@@ -33,6 +33,7 @@ from ..sparrow_distribute.constants import DistributeStatus
 from ..sparrow_promotions.models import Coupon
 from .constants import Aftersale_Number_Refund_Status
 from .constants import AfsLineGenerateFrom
+from .constants import AfsVersionConst
 from . import APP_LABEL
 
 
@@ -226,7 +227,7 @@ class Afs(BaseModelTimeAndDeleted):
     pay_method = models.CharField("支付方法", max_length=24,choices=PayMethod.PAY_METHOD_CHOICES, blank=True, null=True, default=PayMethod.ONCE)
 
     # 退货重算-售后单版本号
-    afs_version = models.CharField("售后版本号", max_length=12, blank=True, null=True, db_index=True)
+    afs_version = models.CharField("售后版本号", max_length=12, blank=True, null=True, db_index=True, default=AfsVersionConst.V2)
 
     class Meta:
         app_label = APP_LABEL
@@ -672,7 +673,7 @@ class AfsLine(BaseModelTimeAndDeleted):
     return_id = models.CharField("微信组件退货ID", max_length=64, blank=True, null=True)
 
     # 退货重算-售后版本号
-    afs_version = models.CharField("售后版本号", max_length=12, blank=True, null=True, db_index=True)
+    afs_version = models.CharField("售后版本号", max_length=12, blank=True, null=True, db_index=True, default=AfsVersionConst.V2)
     # 售后数据来源
     generate_from = models.CharField(
         "数据来源", max_length=12, blank=True, null=True, 
@@ -1370,3 +1371,38 @@ class VlinesOnlyRefund(models.Model):
 
     class Meta:
         app_label = 'sparrow_aftersale'
+
+
+class AfsVlinesOnlyRefundPoint(models.Model):
+    ''' 由仅退差价后在各行扣除的积分 '''
+    id = models.CharField("id", primary_key=True, max_length=40, default=get_uuid4_hex)
+    vline_id = models.PositiveIntegerField('VLine ID', blank=True, null=True, db_index=True)
+    aftersale_id = models.PositiveIntegerField('AfterSale ID', blank=True, null=True, db_index=True)
+    aftersale_number = models.CharField("退单号", max_length=40, db_index=True)
+    order_id = models.PositiveIntegerField('Order Id', blank=True, null=True, db_index=True)
+    order_number = models.CharField("订单编号", max_length=64, blank=True, null=True)
+    line_id = models.PositiveIntegerField('Line Id', blank=True, null=True, db_index=True)
+    points = models.PositiveIntegerField('Points', blank=True, null=True, db_index=True, default=0)
+
+    class Meta:
+        app_label = 'sparrow_aftersale'
+
+
+class AfsVersionSuite(models.Model):
+    afsid_v2 = models.PositiveIntegerField("AfsID_V2", primary_key=True)
+    afsid_v3 = models.PositiveIntegerField("AfsID_v3")
+
+    class Meta:
+        app_label = 'sparrow_aftersale'
+
+
+class AfsVlinesPointsCharge(models.Model):
+    ''' V3版本售后需要在用户积分不够扣的情况下, 提供给客服编辑扣除积分的空间 '''
+    aftersale_id = models.PositiveIntegerField("AfsID_V2", primary_key=True)
+    # 由退货重算生成的原始积分
+    calc_points = models.PositiveIntegerField("calc_points")
+    # 由客服编辑后的积分
+    edit_points = models.PositiveIntegerField("edit_points")
+
+    class Meta:
+        app_label = 'sparrow_aftersale'
